Query$getQuestionsbyFormWithResponsesStatsPaginated$getQuestionsbyFormWithResponsesStatsPaginated$objects$settings$smiley$levels class
Constructors
- Query$getQuestionsbyFormWithResponsesStatsPaginated$getQuestionsbyFormWithResponsesStatsPaginated$objects$settings$smiley$levels({required double rank, String? icon, Query$getQuestionsbyFormWithResponsesStatsPaginated$getQuestionsbyFormWithResponsesStatsPaginated$objects$settings$smiley$levels$picture? picture})
-
Query$getQuestionsbyFormWithResponsesStatsPaginated$getQuestionsbyFormWithResponsesStatsPaginated$objects$settings$smiley$levels.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ CopyWith$Query$getQuestionsbyFormWithResponsesStatsPaginated$getQuestionsbyFormWithResponsesStatsPaginated$objects$settings$smiley$levels<
Query$getQuestionsbyFormWithResponsesStatsPaginated$getQuestionsbyFormWithResponsesStatsPaginated$objects$settings$smiley$levels> -
Available on Query$getQuestionsbyFormWithResponsesStatsPaginated$getQuestionsbyFormWithResponsesStatsPaginated$objects$settings$smiley$levels, provided by the UtilityExtension$Query$getQuestionsbyFormWithResponsesStatsPaginated$getQuestionsbyFormWithResponsesStatsPaginated$objects$settings$smiley$levels extension
no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- icon → String?
-
final
- picture → Query$getQuestionsbyFormWithResponsesStatsPaginated$getQuestionsbyFormWithResponsesStatsPaginated$objects$settings$smiley$levels$picture?
-
final
- rank → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override