Mutation$createOutboundCorporateNotification class
- Available extensions
Constructors
- Mutation$createOutboundCorporateNotification({required Mutation$createOutboundCorporateNotification$createOutboundCorporateNotification createOutboundCorporateNotification})
-
Mutation$createOutboundCorporateNotification.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ CopyWith$Mutation$createOutboundCorporateNotification<
Mutation$createOutboundCorporateNotification> -
Available on Mutation$createOutboundCorporateNotification, provided by the UtilityExtension$Mutation$createOutboundCorporateNotification extension
no setter - createOutboundCorporateNotification → Mutation$createOutboundCorporateNotification$createOutboundCorporateNotification
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override