Mutation$performDonationActivity$performDonationActivity class

Available extensions

Constructors

Mutation$performDonationActivity$performDonationActivity({required String message, required bool success, String $__typename = 'SuccessResponseDtoType'})
Mutation$performDonationActivity$performDonationActivity.fromJson(Map<String, dynamic> json)
factory

Properties

$__typename String
final
copyWith CopyWith$Mutation$performDonationActivity$performDonationActivity<Mutation$performDonationActivity$performDonationActivity>

Available on Mutation$performDonationActivity$performDonationActivity, provided by the UtilityExtension$Mutation$performDonationActivity$performDonationActivity extension

no setter
hashCode int
The hash code for this object.
no setteroverride
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override