Query$getUserWalletWithReputations$getUserWalletWithReputations$reputationLevels class
Constructors
- Query$getUserWalletWithReputations$getUserWalletWithReputations$reputationLevels({required String id, int? rank, String? color, int? period, required DateTime createdAt, required DateTime updatedAt, int? lossAmount, int? lossPoints, int? nextLevelMax, int? turnoverPoints, int? inactivityCycle, String? reputationLevel, Query$getUserWalletWithReputations$getUserWalletWithReputations$reputationLevels$picture? picture, Query$getUserWalletWithReputations$getUserWalletWithReputations$reputationLevels$perks? perks, Query$getUserWalletWithReputations$getUserWalletWithReputations$reputationLevels$levelInterval? levelInterval, String $__typename = 'ReputationWithoutTargetType'})
-
Query$getUserWalletWithReputations$getUserWalletWithReputations$reputationLevels.fromJson(Map<
String, dynamic> json) -
factory
Properties
- $__typename → String
-
final
- color → String?
-
final
-
copyWith
→ CopyWith$Query$getUserWalletWithReputations$getUserWalletWithReputations$reputationLevels<
Query$getUserWalletWithReputations$getUserWalletWithReputations$reputationLevels> -
Available on Query$getUserWalletWithReputations$getUserWalletWithReputations$reputationLevels, provided by the UtilityExtension$Query$getUserWalletWithReputations$getUserWalletWithReputations$reputationLevels extension
no setter - createdAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- inactivityCycle → int?
-
final
- levelInterval → Query$getUserWalletWithReputations$getUserWalletWithReputations$reputationLevels$levelInterval?
-
final
- lossAmount → int?
-
final
- lossPoints → int?
-
final
- nextLevelMax → int?
-
final
- period → int?
-
final
- perks → Query$getUserWalletWithReputations$getUserWalletWithReputations$reputationLevels$perks?
-
final
- picture → Query$getUserWalletWithReputations$getUserWalletWithReputations$reputationLevels$picture?
-
final
- rank → int?
-
final
- reputationLevel → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- turnoverPoints → int?
-
final
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override