Query$getUserWalletWithReputations class

Available extensions

Constructors

Query$getUserWalletWithReputations({required Query$getUserWalletWithReputations$getUserWalletWithReputations getUserWalletWithReputations, String $__typename = 'Query'})
Query$getUserWalletWithReputations.fromJson(Map<String, dynamic> json)
factory

Properties

$__typename String
final
copyWith CopyWith$Query$getUserWalletWithReputations<Query$getUserWalletWithReputations>

Available on Query$getUserWalletWithReputations, provided by the UtilityExtension$Query$getUserWalletWithReputations extension

no setter
getUserWalletWithReputations Query$getUserWalletWithReputations$getUserWalletWithReputations
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override