CopyWith$Mutation$markAllMessageAsSeen<TRes> class
abstract
Constructors
- CopyWith$Mutation$markAllMessageAsSeen(Mutation$markAllMessageAsSeen instance, TRes then(Mutation$markAllMessageAsSeen))
-
factory
- CopyWith$Mutation$markAllMessageAsSeen.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
markAllMessageAsSeen
→ CopyWith$Mutation$markAllMessageAsSeen$markAllMessageAsSeen<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{Mutation$markAllMessageAsSeen$markAllMessageAsSeen? markAllMessageAsSeen}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited