CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$media<TRes> class
abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{List< Mutation$sendMessageToTarget$sendMessageToTarget$media$video> ? video, List<Mutation$sendMessageToTarget$sendMessageToTarget$media$picture> ? picture}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
picture(
Iterable< Mutation$sendMessageToTarget$sendMessageToTarget$media$picture> ? _fn(Iterable<CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$media$picture< ?)) → TResMutation$sendMessageToTarget$sendMessageToTarget$media$picture> > -
toString(
) → String -
A string representation of this object.
inherited
-
video(
Iterable< Mutation$sendMessageToTarget$sendMessageToTarget$media$video> ? _fn(Iterable<CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$media$video< ?)) → TResMutation$sendMessageToTarget$sendMessageToTarget$media$video> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited