CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$creator$picture<TRes> class
abstract
Constructors
- CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$creator$picture(Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$creator$picture instance, TRes then(Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$creator$picture))
-
factory
- CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$creator$picture.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{String? baseUrl, String? path, int? width, int? height, int? x, int? y, String? alt, String? $__typename}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited