CopyWith$Query$countUnseenMessages<TRes> class
abstract
Constructors
- CopyWith$Query$countUnseenMessages(Query$countUnseenMessages instance, TRes then(Query$countUnseenMessages))
-
factory
- CopyWith$Query$countUnseenMessages.stub(TRes res)
-
factory
Properties
-
countUnseenMessages
→ CopyWith$Query$countUnseenMessages$countUnseenMessages<
TRes> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{Query$countUnseenMessages$countUnseenMessages? countUnseenMessages}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited