CopyWith$Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper<TRes> class
abstract
Constructors
- CopyWith$Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper(Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper instance, TRes then(Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper))
-
factory
- CopyWith$Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
picture
→ CopyWith$Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper$picture<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper$picture? picture, List< String> ? gradientColors, String? assetImage}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited