Mutation$markAllMessageAsSeen class

Available extensions

Constructors

Mutation$markAllMessageAsSeen({required Mutation$markAllMessageAsSeen$markAllMessageAsSeen markAllMessageAsSeen, String $__typename = 'Mutation'})
Mutation$markAllMessageAsSeen.fromJson(Map<String, dynamic> json)
factory

Properties

$__typename String
final
copyWith CopyWith$Mutation$markAllMessageAsSeen<Mutation$markAllMessageAsSeen>

Available on Mutation$markAllMessageAsSeen, provided by the UtilityExtension$Mutation$markAllMessageAsSeen extension

no setter
hashCode int
The hash code for this object.
no setteroverride
markAllMessageAsSeen Mutation$markAllMessageAsSeen$markAllMessageAsSeen
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override