Mutation$sendMessageToTarget$sendMessageToTarget$location class
- Available extensions
Constructors
-
Mutation$sendMessageToTarget$sendMessageToTarget$location({Enum$ZoneTypesEnum? type, List<
double> ? coordinates}) -
Mutation$sendMessageToTarget$sendMessageToTarget$location.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
coordinates
→ List<
double> ? -
final
-
copyWith
→ CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$location<
Mutation$sendMessageToTarget$sendMessageToTarget$location> -
Available on Mutation$sendMessageToTarget$sendMessageToTarget$location, provided by the UtilityExtension$Mutation$sendMessageToTarget$sendMessageToTarget$location extension
no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Enum$ZoneTypesEnum?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override