Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media class
Constructors
-
Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media({List<
Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media$video> ? video, List<Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media$picture> ? picture}) -
Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media<
Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media> -
Available on Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media, provided by the UtilityExtension$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media extension
no setter - hashCode → int
-
The hash code for this object.
no setteroverride
-
picture
→ List<
Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media$picture> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
video
→ List<
Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media$video> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override