Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage class
Constructors
- Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage({String? text, String? gif, String? sticker, Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media? media, Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$location? location, Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$custom? custom, bool? unread, required DateTime createdAt, required DateTime updatedAt})
-
Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage<
Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage> -
Available on Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage, provided by the UtilityExtension$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage extension
no setter - createdAt → DateTime
-
final
- custom → Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$custom?
-
final
- gif → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- location → Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$location?
-
final
- media → Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sticker → String?
-
final
- text → String?
-
final
- unread → bool?
-
final
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override