Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup class
- Available extensions
Constructors
- Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup({required String id, String? name, bool? mute, Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$creator? creator, Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$target? target, Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$profilePicture? profilePicture, Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$wallpaper? wallpaper, Enum$MessageSoundEnum? sound, bool? isDirectMessage, Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$members? members, Enum$MessageGroupStatusEnum? status, Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage? lastMessage, int? unreadCount, required DateTime createdAt, required DateTime updatedAt})
-
Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup<
Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup> -
Available on Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup, provided by the UtilityExtension$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup extension
no setter - createdAt → DateTime
-
final
- creator → Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$creator?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- isDirectMessage → bool?
-
final
- lastMessage → Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage?
-
final
- members → Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$members?
-
final
- mute → bool?
-
final
- name → String?
-
final
- profilePicture → Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$profilePicture?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sound → Enum$MessageSoundEnum?
-
final
- status → Enum$MessageGroupStatusEnum?
-
final
- target → Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$target?
-
final
- unreadCount → int?
-
final
- updatedAt → DateTime
-
final
- wallpaper → Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$wallpaper?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override