Mutation$sendMessageToTarget$sendMessageToTarget$seenBy class
- Available extensions
Constructors
- Mutation$sendMessageToTarget$sendMessageToTarget$seenBy({required String id, String? email, Enum$Gender? gender, Enum$UserStatus? status, String? lastName, String? username, String? firstName, Mutation$sendMessageToTarget$sendMessageToTarget$seenBy$phone? phone, Mutation$sendMessageToTarget$sendMessageToTarget$seenBy$picture? picture})
-
Mutation$sendMessageToTarget$sendMessageToTarget$seenBy.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$seenBy<
Mutation$sendMessageToTarget$sendMessageToTarget$seenBy> -
Available on Mutation$sendMessageToTarget$sendMessageToTarget$seenBy, provided by the UtilityExtension$Mutation$sendMessageToTarget$sendMessageToTarget$seenBy extension
no setter - email → String?
-
final
- firstName → String?
-
final
- gender → Enum$Gender?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- lastName → String?
-
final
- phone → Mutation$sendMessageToTarget$sendMessageToTarget$seenBy$phone?
-
final
- picture → Mutation$sendMessageToTarget$sendMessageToTarget$seenBy$picture?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → Enum$UserStatus?
-
final
- username → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override