Mutation$sendMessageToTarget$sendMessageToTarget class
- Available extensions
Constructors
-
Mutation$sendMessageToTarget$sendMessageToTarget({required String id, String? gif, String? text, String? sticker, required DateTime createdAt, required DateTime updatedAt, required Mutation$sendMessageToTarget$sendMessageToTarget$sender sender, Mutation$sendMessageToTarget$sendMessageToTarget$custom? custom, Mutation$sendMessageToTarget$sendMessageToTarget$location? location, List<
Mutation$sendMessageToTarget$sendMessageToTarget$seenBy> ? seenBy, Mutation$sendMessageToTarget$sendMessageToTarget$media? media, required Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup messageGroup}) -
Mutation$sendMessageToTarget$sendMessageToTarget.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget<
Mutation$sendMessageToTarget$sendMessageToTarget> -
Available on Mutation$sendMessageToTarget$sendMessageToTarget, provided by the UtilityExtension$Mutation$sendMessageToTarget$sendMessageToTarget extension
no setter - createdAt → DateTime
-
final
- custom → Mutation$sendMessageToTarget$sendMessageToTarget$custom?
-
final
- gif → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- location → Mutation$sendMessageToTarget$sendMessageToTarget$location?
-
final
- media → Mutation$sendMessageToTarget$sendMessageToTarget$media?
-
final
- messageGroup → Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
seenBy
→ List<
Mutation$sendMessageToTarget$sendMessageToTarget$seenBy> ? -
final
- sender → Mutation$sendMessageToTarget$sendMessageToTarget$sender
-
final
- sticker → String?
-
final
- text → String?
-
final
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override