Query$countUnseenMessages$countUnseenMessages class

Available extensions

Constructors

Query$countUnseenMessages$countUnseenMessages({required int unseenMessagesCount})
Query$countUnseenMessages$countUnseenMessages.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith CopyWith$Query$countUnseenMessages$countUnseenMessages<Query$countUnseenMessages$countUnseenMessages>

Available on Query$countUnseenMessages$countUnseenMessages, provided by the UtilityExtension$Query$countUnseenMessages$countUnseenMessages extension

no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unseenMessagesCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override