Query$countUnseenMessages class

Available extensions

Properties

copyWith CopyWith$Query$countUnseenMessages<Query$countUnseenMessages>

Available on Query$countUnseenMessages, provided by the UtilityExtension$Query$countUnseenMessages extension

no setter
countUnseenMessages Query$countUnseenMessages$countUnseenMessages
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override