Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper class
Constructors
-
Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper({Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper$picture? picture, List<
String> ? gradientColors, String? assetImage}) -
Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper.fromJson(Map<
String, dynamic> json) -
factory
Properties
- assetImage → String?
-
final
-
copyWith
→ CopyWith$Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper<
Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper> -
Available on Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper, provided by the UtilityExtension$Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper extension
no setter -
gradientColors
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- picture → Query$getMessagesByMemberPaginated$getMessagesByMemberPaginated$objects$messageGroup$wallpaper$picture?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override