CopyWith$Mutation$updateUser$updateUser<TRes> class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
phone CopyWith$Mutation$updateUser$updateUser$phone<TRes>
no setter
picture CopyWith$Mutation$updateUser$updateUser$picture<TRes>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socialLoginData CopyWith$Mutation$updateUser$updateUser$socialLoginData<TRes>
no setter

Methods

call({String? id, String? email, Enum$Gender? gender, String? locale, bool? widget, String? lastName, String? username, String? firstName, DateTime? createdAt, DateTime? updatedAt, bool? isMailValid, DateTime? dateOfBirth, Enum$MobileThemesEnum? mobileTheme, Enum$MaritalStatus? maritalStatus, Mutation$updateUser$updateUser$phone? phone, Mutation$updateUser$updateUser$picture? picture, List<Mutation$updateUser$updateUser$residentialAddress>? residentialAddress, List<Mutation$updateUser$updateUser$chatContact>? chatContact, List<Mutation$updateUser$updateUser$socialMedia>? socialMedia, Mutation$updateUser$updateUser$socialLoginData? socialLoginData, List<Mutation$updateUser$updateUser$education>? education, List<Mutation$updateUser$updateUser$work>? work, List<String>? hobbies, List<String>? interests}) → TRes
chatContact(Iterable<Mutation$updateUser$updateUser$chatContact>? _fn(Iterable<CopyWith$Mutation$updateUser$updateUser$chatContact<Mutation$updateUser$updateUser$chatContact>>?)) → TRes
education(Iterable<Mutation$updateUser$updateUser$education>? _fn(Iterable<CopyWith$Mutation$updateUser$updateUser$education<Mutation$updateUser$updateUser$education>>?)) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
residentialAddress(Iterable<Mutation$updateUser$updateUser$residentialAddress>? _fn(Iterable<CopyWith$Mutation$updateUser$updateUser$residentialAddress<Mutation$updateUser$updateUser$residentialAddress>>?)) → TRes
socialMedia(Iterable<Mutation$updateUser$updateUser$socialMedia>? _fn(Iterable<CopyWith$Mutation$updateUser$updateUser$socialMedia<Mutation$updateUser$updateUser$socialMedia>>?)) → TRes
toString() String
A string representation of this object.
inherited
work(Iterable<Mutation$updateUser$updateUser$work>? _fn(Iterable<CopyWith$Mutation$updateUser$updateUser$work<Mutation$updateUser$updateUser$work>>?)) → TRes

Operators

operator ==(Object other) bool
The equality operator.
inherited