CopyWith$Query$user$user$residentialAddress<TRes> class
abstract
Constructors
- CopyWith$Query$user$user$residentialAddress(Query$user$user$residentialAddress instance, TRes then(Query$user$user$residentialAddress))
-
factory
- CopyWith$Query$user$user$residentialAddress.stub(TRes res)
-
factory
Properties
-
country
→ CopyWith$Query$user$user$residentialAddress$country<
TRes> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
location
→ CopyWith$Query$user$user$residentialAddress$location<
TRes> -
no setter
-
owner
→ CopyWith$Query$user$user$residentialAddress$owner<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ CopyWith$Query$user$user$residentialAddress$state<
TRes> -
no setter
Methods
-
call(
{String? city, String? address, String? postCode, Query$user$user$residentialAddress$location? location, Query$user$user$residentialAddress$country? country, Query$user$user$residentialAddress$state? state, Query$user$user$residentialAddress$owner? owner}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited