Mutation$updateUser$updateUser$education$city class
- Available extensions
Constructors
- Mutation$updateUser$updateUser$education$city({required String id, required String name, String? adminName, Enum$StateCapitalEnum? capital, String? population, String? ascii, String? lat, String? lng, Mutation$updateUser$updateUser$education$city$country? country, required DateTime createdAt, required DateTime updatedAt, Mutation$updateUser$updateUser$education$city$flagSquare? flagSquare, Mutation$updateUser$updateUser$education$city$flagWide? flagWide})
-
Mutation$updateUser$updateUser$education$city.fromJson(Map<
String, dynamic> json) -
factory
Properties
- adminName → String?
-
final
- ascii → String?
-
final
- capital → Enum$StateCapitalEnum?
-
final
-
copyWith
→ CopyWith$Mutation$updateUser$updateUser$education$city<
Mutation$updateUser$updateUser$education$city> -
Available on Mutation$updateUser$updateUser$education$city, provided by the UtilityExtension$Mutation$updateUser$updateUser$education$city extension
no setter - country → Mutation$updateUser$updateUser$education$city$country?
-
final
- createdAt → DateTime
-
final
- flagSquare → Mutation$updateUser$updateUser$education$city$flagSquare?
-
final
- flagWide → Mutation$updateUser$updateUser$education$city$flagWide?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- lat → String?
-
final
- lng → String?
-
final
- name → String
-
final
- population → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override