Query$user$user$residentialAddress$location class

Available extensions

Constructors

Query$user$user$residentialAddress$location({Enum$ZoneTypesEnum? type, List<double>? coordinates, String $__typename = 'LonLatType'})
Query$user$user$residentialAddress$location.fromJson(Map<String, dynamic> json)
factory

Properties

$__typename String
final
coordinates List<double>?
final
copyWith CopyWith$Query$user$user$residentialAddress$location<Query$user$user$residentialAddress$location>

Available on Query$user$user$residentialAddress$location, provided by the UtilityExtension$Query$user$user$residentialAddress$location extension

no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Enum$ZoneTypesEnum?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override