Query$user$user$residentialAddress class
- Available extensions
Constructors
- Query$user$user$residentialAddress({String? city, String? address, String? postCode, Query$user$user$residentialAddress$location? location, Query$user$user$residentialAddress$country? country, Query$user$user$residentialAddress$state? state, Query$user$user$residentialAddress$owner? owner})
-
Query$user$user$residentialAddress.fromJson(Map<
String, dynamic> json) -
factory
Properties
- address → String?
-
final
- city → String?
-
final
-
copyWith
→ CopyWith$Query$user$user$residentialAddress<
Query$user$user$residentialAddress> -
Available on Query$user$user$residentialAddress, provided by the UtilityExtension$Query$user$user$residentialAddress extension
no setter - country → Query$user$user$residentialAddress$country?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- location → Query$user$user$residentialAddress$location?
-
final
- owner → Query$user$user$residentialAddress$owner?
-
final
- postCode → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → Query$user$user$residentialAddress$state?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override