Query$user class

Available extensions

Constructors

Query$user({required Query$user$user user})
Query$user.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith CopyWith$Query$user<Query$user>

Available on Query$user, provided by the UtilityExtension$Query$user extension

no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user Query$user$user
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override