CopyWith$Input$AdhocTransactionUpdateInput<TRes> class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
prelevel CopyWith$Input$RemunerationBaseInput<TRes>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({String? title, String? code, String? description, List<Input$AdhocTransactionTranslationInput>? translation, String? wallet, List<Input$RemunerationWithReputationInput>? remunerations, Input$RemunerationBaseInput? prelevel}) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remunerations(Iterable<Input$RemunerationWithReputationInput>? _fn(Iterable<CopyWith$Input$RemunerationWithReputationInput<Input$RemunerationWithReputationInput>>?)) → TRes
toString() String
A string representation of this object.
inherited
translation(Iterable<Input$AdhocTransactionTranslationInput>? _fn(Iterable<CopyWith$Input$AdhocTransactionTranslationInput<Input$AdhocTransactionTranslationInput>>?)) → TRes

Operators

operator ==(Object other) bool
The equality operator.
inherited