CopyWith$Input$EventTicketBundleInput<TRes> class
abstract
Constructors
- CopyWith$Input$EventTicketBundleInput(Input$EventTicketBundleInput instance, TRes then(Input$EventTicketBundleInput))
-
factory
- CopyWith$Input$EventTicketBundleInput.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{String? title, String? zone, DateTime? from, DateTime? to, String? price}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited