CopyWith$Input$FreebieInput<TRes> class
abstract
Constructors
- CopyWith$Input$FreebieInput(Input$FreebieInput instance, TRes then(Input$FreebieInput))
-
factory
- CopyWith$Input$FreebieInput.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
target
→ CopyWith$Input$TargetACIInput<
TRes> -
no setter
Methods
-
call(
{bool? enable, String? amount, int? rate, Enum$RecurrenceType? frequency, List< Input$FreebieSchedularInput> ? schedular, Input$TargetACIInput? target}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
schedular(
Iterable< Input$FreebieSchedularInput> ? _fn(Iterable<CopyWith$Input$FreebieSchedularInput< ?)) → TResInput$FreebieSchedularInput> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited