CopyWith$Input$FreebieSchedularInput<TRes> class
abstract
Constructors
- CopyWith$Input$FreebieSchedularInput(Input$FreebieSchedularInput instance, TRes then(Input$FreebieSchedularInput))
-
factory
- CopyWith$Input$FreebieSchedularInput.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
actions(
Iterable< Input$FreebieSchedularActionsInput> ? _fn(Iterable<CopyWith$Input$FreebieSchedularActionsInput< ?)) → TResInput$FreebieSchedularActionsInput> > -
call(
{Enum$DayEnum? dayOfWeek, List< Input$FreebieSchedularActionsInput> ? actions}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited