CopyWith$Input$FreebieUpdateInput<TRes> class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({bool? enable, String? amount, int? rate, Enum$RecurrenceType? frequency, List<Input$FreebieSchedularInput>? schedular}) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
schedular(Iterable<Input$FreebieSchedularInput>? _fn(Iterable<CopyWith$Input$FreebieSchedularInput<Input$FreebieSchedularInput>>?)) → TRes
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited