CopyWith$Input$GameAssetsInput<TRes> class
abstract
Constructors
- CopyWith$Input$GameAssetsInput(Input$GameAssetsInput instance, TRes then(Input$GameAssetsInput))
-
factory
- CopyWith$Input$GameAssetsInput.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{List< Input$GameAssetDetailInput> ? images, String? font, List<Input$GameAssetDetailInput> ? sound}) → TRes -
images(
Iterable< Input$GameAssetDetailInput> ? _fn(Iterable<CopyWith$Input$GameAssetDetailInput< ?)) → TResInput$GameAssetDetailInput> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sound(
Iterable< Input$GameAssetDetailInput> ? _fn(Iterable<CopyWith$Input$GameAssetDetailInput< ?)) → TResInput$GameAssetDetailInput> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited