CopyWith$Input$GameIntegrationCustomInput<TRes> class
abstract
Constructors
- CopyWith$Input$GameIntegrationCustomInput(Input$GameIntegrationCustomInput instance, TRes then(Input$GameIntegrationCustomInput))
-
factory
- CopyWith$Input$GameIntegrationCustomInput.stub(TRes res)
-
factory
Properties
-
assets
→ CopyWith$Input$GameAssetsInput<
TRes> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
media
→ CopyWith$Input$MediaInput<
TRes> -
no setter
-
point
→ CopyWith$Input$GamePointInput<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
settings
→ CopyWith$Input$GameSettingsInput<
TRes> -
no setter
Methods
-
call(
{String? title, String? description, Input$GamePointInput? point, Input$MediaInput? media, List< Input$GameTranslationInput> ? translation, Input$GameAssetsInput? assets, Input$GameSettingsInput? settings}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
translation(
Iterable< Input$GameTranslationInput> ? _fn(Iterable<CopyWith$Input$GameTranslationInput< ?)) → TResInput$GameTranslationInput> >
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited