CopyWith$Input$GameIntegrationUpdateInput<TRes> class
abstract
Constructors
- CopyWith$Input$GameIntegrationUpdateInput(Input$GameIntegrationUpdateInput instance, TRes then(Input$GameIntegrationUpdateInput))
-
factory
- CopyWith$Input$GameIntegrationUpdateInput.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{List< Input$GameGroupInput> ? gameGroups, List<Input$GameIntegrationSettingsInput> ? games}) → TRes -
gameGroups(
Iterable< Input$GameGroupInput> ? _fn(Iterable<CopyWith$Input$GameGroupInput< ?)) → TResInput$GameGroupInput> > -
games(
Iterable< Input$GameIntegrationSettingsInput> ? _fn(Iterable<CopyWith$Input$GameIntegrationSettingsInput< ?)) → TResInput$GameIntegrationSettingsInput> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited