CopyWith$Input$GameOrderInput<TRes> class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
qualitativeItem CopyWith$Input$GameOrderQualitativeItemInput<TRes>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
standardItem CopyWith$Input$GameOrderStandardItemInput<TRes>
no setter
target CopyWith$Input$TargetACIInput<TRes>
no setter

Methods

call({Input$GameOrderStandardItemInput? standardItem, Input$GameOrderQualitativeItemInput? qualitativeItem, Input$TargetACIInput? target, String? game}) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited