CopyWith$Input$GameSettingsInput<TRes> class abstract

Properties

cost CopyWith$Input$GameSettingsCostInput<TRes>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({String? color, String? gameConfigs, Input$GameSettingsCostInput? cost, List<Input$GameSettingsItemInput>? items}) → TRes
items(Iterable<Input$GameSettingsItemInput>? _fn(Iterable<CopyWith$Input$GameSettingsItemInput<Input$GameSettingsItemInput>>?)) → TRes
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited