CopyWith$Input$InsightsKpisInput<TRes> class
abstract
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call({double? impressions, double? impressions_change, double? clicks, double? clicks_change, double? ctr, double? ctr_change, double? conversions, double? conversions_change, double? conversion_rate, double? conversion_rate_change, double? revenue, double? revenue_change, double? rpm, double? rpm_change})
→ TRes
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited