CopyWith$Input$SetupLoyaltyLevelsAiInput<TRes> class
abstract
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call({double? numLevels, double? avgBasketValue, double? rewardPercent, double? inactiveDays, String? businessDescription, String? tone, List<String>? brandColors, String? language, double? pointValue, String? currency, double? avgMonthlyVisits})
→ TRes
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited