CopyWith$Input$UpdateCouponSettingsInput<TRes> class
abstract
Constructors
- CopyWith$Input$UpdateCouponSettingsInput(Input$UpdateCouponSettingsInput instance, TRes then(Input$UpdateCouponSettingsInput))
-
factory
- CopyWith$Input$UpdateCouponSettingsInput.stub(TRes res)
-
factory
Properties
-
discount
→ CopyWith$Input$DiscountDtoInput<
TRes> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
number
→ CopyWith$Input$NumberInput<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{bool? enabled, Input$DiscountDtoInput? discount, String? amount, Input$NumberInput? number}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited