Input$AdhocTransactionInput class

Constructors

Input$AdhocTransactionInput({bool? enabled, required String title, required String code, String? description, List<Input$AdhocTransactionTranslationInput>? translation, Input$TargetACIInput? target, String? wallet, List<Input$RemunerationWithReputationInput>? remunerations, Input$RemunerationBaseInput? prelevel})
factory
Input$AdhocTransactionInput.fromJson(Map<String, dynamic> data)
factory

Properties

code String
no setter
copyWith CopyWith$Input$AdhocTransactionInput<Input$AdhocTransactionInput>
no setter
description String?
no setter
enabled bool?
no setter
hashCode int
The hash code for this object.
no setteroverride
prelevel Input$RemunerationBaseInput?
no setter
remunerations List<Input$RemunerationWithReputationInput>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Input$TargetACIInput?
no setter
title String
no setter
translation List<Input$AdhocTransactionTranslationInput>?
no setter
wallet String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override