Input$AdhocTransactionUpdateInput class

Properties

code String?
no setter
copyWith CopyWith$Input$AdhocTransactionUpdateInput<Input$AdhocTransactionUpdateInput>
no setter
description String?
no setter
hashCode int
The hash code for this object.
no setteroverride
prelevel Input$RemunerationBaseInput?
no setter
remunerations List<Input$RemunerationWithReputationInput>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
no setter
translation List<Input$AdhocTransactionTranslationInput>?
no setter
wallet String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override