Input$BetOrderOddsOddsInput class

Constructors

Input$BetOrderOddsOddsInput({required int id, required String name, required String value, required String odd, required int bet})
factory
Input$BetOrderOddsOddsInput.fromJson(Map<String, dynamic> data)
factory

Properties

bet int
no setter
copyWith CopyWith$Input$BetOrderOddsOddsInput<Input$BetOrderOddsOddsInput>
no setter
hashCode int
The hash code for this object.
no setteroverride
id int
no setter
name String
no setter
odd String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override