Input$DeductAmountFromUserInput class

Constructors

Input$DeductAmountFromUserInput({String? amount, String? location, String? game, String? userId, String? card, Enum$TransactionTypeEnum? reason, required Input$TargetACIInput target})
factory
Input$DeductAmountFromUserInput.fromJson(Map<String, dynamic> data)
factory

Properties

amount String?
no setter
card String?
no setter
copyWith CopyWith$Input$DeductAmountFromUserInput<Input$DeductAmountFromUserInput>
no setter
game String?
no setter
hashCode int
The hash code for this object.
no setteroverride
location String?
no setter
reason Enum$TransactionTypeEnum?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Input$TargetACIInput
no setter
userId String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override