Input$EventTicketBundleInput class

Constructors

Input$EventTicketBundleInput({String? title, String? zone, DateTime? from, DateTime? to, required String price})
factory
Input$EventTicketBundleInput.fromJson(Map<String, dynamic> data)
factory

Properties

copyWith CopyWith$Input$EventTicketBundleInput<Input$EventTicketBundleInput>
no setter
from DateTime?
no setter
hashCode int
The hash code for this object.
no setteroverride
price String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
no setter
to DateTime?
no setter
zone String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override