Input$FreebieInput class
Constructors
-
Input$FreebieInput({required bool enable, required String amount, required int rate, required Enum$RecurrenceType frequency, List<
Input$FreebieSchedularInput> ? schedular, Input$TargetACIInput? target}) -
factory
-
Input$FreebieInput.fromJson(Map<
String, dynamic> data) -
factory
Properties
- amount → String
-
no setter
-
copyWith
→ CopyWith$Input$FreebieInput<
Input$FreebieInput> -
no setter
- enable → bool
-
no setter
- frequency → Enum$RecurrenceType
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- rate → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schedular
→ List<
Input$FreebieSchedularInput> ? -
no setter
- target → Input$TargetACIInput?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override