Input$FreebieSchedularActionsInput class

Constructors

Input$FreebieSchedularActionsInput({required String amount, required int count, required String time})
factory
Input$FreebieSchedularActionsInput.fromJson(Map<String, dynamic> data)
factory

Properties

amount String
no setter
copyWith CopyWith$Input$FreebieSchedularActionsInput<Input$FreebieSchedularActionsInput>
no setter
count int
no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override