Input$FreebieTransactionInput class

Constructors

Input$FreebieTransactionInput({double? quantity, String? amount, DateTime? scheduledAt, Input$TargetACIInput? target})
factory
Input$FreebieTransactionInput.fromJson(Map<String, dynamic> data)
factory

Properties

amount String?
no setter
copyWith CopyWith$Input$FreebieTransactionInput<Input$FreebieTransactionInput>
no setter
hashCode int
The hash code for this object.
no setteroverride
quantity double?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduledAt DateTime?
no setter
target Input$TargetACIInput?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override