Input$FreebieUpdateInput class
Constructors
-
Input$FreebieUpdateInput({bool? enable, String? amount, int? rate, Enum$RecurrenceType? frequency, List<
Input$FreebieSchedularInput> ? schedular}) -
factory
-
Input$FreebieUpdateInput.fromJson(Map<
String, dynamic> data) -
factory
Properties
- amount → String?
-
no setter
-
copyWith
→ CopyWith$Input$FreebieUpdateInput<
Input$FreebieUpdateInput> -
no setter
- enable → bool?
-
no setter
- frequency → Enum$RecurrenceType?
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- rate → int?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schedular
→ List<
Input$FreebieSchedularInput> ? -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override