Input$GameIntegrationCustomInput class

Properties

assets Input$GameAssetsInput?
no setter
copyWith CopyWith$Input$GameIntegrationCustomInput<Input$GameIntegrationCustomInput>
no setter
description String?
no setter
hashCode int
The hash code for this object.
no setteroverride
media Input$MediaInput?
no setter
point Input$GamePointInput?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings Input$GameSettingsInput?
no setter
title String?
no setter
translation List<Input$GameTranslationInput>?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override