Input$GameOrderInput class

Constructors

Input$GameOrderInput({Input$GameOrderStandardItemInput? standardItem, Input$GameOrderQualitativeItemInput? qualitativeItem, required Input$TargetACIInput target, String? game})
factory
Input$GameOrderInput.fromJson(Map<String, dynamic> data)
factory

Properties

copyWith CopyWith$Input$GameOrderInput<Input$GameOrderInput>
no setter
game String?
no setter
hashCode int
The hash code for this object.
no setteroverride
qualitativeItem Input$GameOrderQualitativeItemInput?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
standardItem Input$GameOrderStandardItemInput?
no setter
target Input$TargetACIInput
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override