Input$GameRewardsFilterInput class

Constructors

Input$GameRewardsFilterInput({required Input$TargetACIInput target, String? game, required int year, required int cycleNumber, required Enum$LeaderboardCycleEnum cycle, String? gameGroup})
factory
Input$GameRewardsFilterInput.fromJson(Map<String, dynamic> data)
factory

Properties

copyWith CopyWith$Input$GameRewardsFilterInput<Input$GameRewardsFilterInput>
no setter
cycle Enum$LeaderboardCycleEnum
no setter
cycleNumber int
no setter
game String?
no setter
gameGroup String?
no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Input$TargetACIInput
no setter
year int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override