Input$GameSettingsInput class

Constructors

Input$GameSettingsInput({String? color, String? gameConfigs, Input$GameSettingsCostInput? cost, List<Input$GameSettingsItemInput>? items})
factory
Input$GameSettingsInput.fromJson(Map<String, dynamic> data)
factory

Properties

color String?
no setter
copyWith CopyWith$Input$GameSettingsInput<Input$GameSettingsInput>
no setter
cost Input$GameSettingsCostInput?
no setter
gameConfigs String?
no setter
hashCode int
The hash code for this object.
no setteroverride
items List<Input$GameSettingsItemInput>?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override