Input$QuestAnalyticsUpdateInput class

Constructors

Input$QuestAnalyticsUpdateInput({required String sessionId, String? userAgent, Input$TargetACIInput? target, bool? impressionViewed, bool? impressionRendered, bool? impressionVisible, bool? hover, bool? click, required String quest})
factory
Input$QuestAnalyticsUpdateInput.fromJson(Map<String, dynamic> data)
factory

Properties

click bool?
no setter
copyWith CopyWith$Input$QuestAnalyticsUpdateInput<Input$QuestAnalyticsUpdateInput>
no setter
hashCode int
The hash code for this object.
no setteroverride
hover bool?
no setter
impressionRendered bool?
no setter
impressionViewed bool?
no setter
impressionVisible bool?
no setter
quest String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
no setter
target Input$TargetACIInput?
no setter
userAgent String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override