Input$RemoveGameGroupInput class

Constructors

Input$RemoveGameGroupInput({required Input$TargetACIInput target, required String code})
factory
Input$RemoveGameGroupInput.fromJson(Map<String, dynamic> data)
factory

Properties

code String
no setter
copyWith CopyWith$Input$RemoveGameGroupInput<Input$RemoveGameGroupInput>
no setter
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Input$TargetACIInput
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override