Input$SetupLoyaltyLevelsAiInput class

Constructors

Input$SetupLoyaltyLevelsAiInput({double? numLevels, double? avgBasketValue, double? rewardPercent, double? inactiveDays, String? businessDescription, String? tone, List<String>? brandColors, String? language, double? pointValue, String? currency, double? avgMonthlyVisits})
factory
Input$SetupLoyaltyLevelsAiInput.fromJson(Map<String, dynamic> data)
factory

Properties

avgBasketValue double?
no setter
avgMonthlyVisits double?
no setter
brandColors List<String>?
no setter
businessDescription String?
no setter
copyWith CopyWith$Input$SetupLoyaltyLevelsAiInput<Input$SetupLoyaltyLevelsAiInput>
no setter
currency String?
no setter
hashCode int
The hash code for this object.
no setteroverride
inactiveDays double?
no setter
language String?
no setter
numLevels double?
no setter
pointValue double?
no setter
rewardPercent double?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tone String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override