Input$UpdateCouponSettingsInput class

Constructors

Input$UpdateCouponSettingsInput({bool? enabled, Input$DiscountDtoInput? discount, String? amount, Input$NumberInput? number})
factory
Input$UpdateCouponSettingsInput.fromJson(Map<String, dynamic> data)
factory

Properties

amount String?
no setter
copyWith CopyWith$Input$UpdateCouponSettingsInput<Input$UpdateCouponSettingsInput>
no setter
discount Input$DiscountDtoInput?
no setter
enabled bool?
no setter
hashCode int
The hash code for this object.
no setteroverride
number Input$NumberInput?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override