Input$VersionsFilterInput class
Constructors
-
Input$VersionsFilterInput({List<
Enum$PlatformEnum> ? platform, bool? requireUpdate, required Input$TargetACIInput target, String? searchString}) -
factory
-
Input$VersionsFilterInput.fromJson(Map<
String, dynamic> data) -
factory
Properties
-
copyWith
→ CopyWith$Input$VersionsFilterInput<
Input$VersionsFilterInput> -
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
-
platform
→ List<
Enum$PlatformEnum> ? -
no setter
- requireUpdate → bool?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchString → String?
-
no setter
- target → Input$TargetACIInput
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override