Input$WidgetIntegrationContentGamesInput class
Constructors
- Input$WidgetIntegrationContentGamesInput({bool? enable, bool? football, bool? betting})
-
factory
-
Input$WidgetIntegrationContentGamesInput.fromJson(Map<
String, dynamic> data) -
factory
Properties
- betting → bool?
-
no setter
-
copyWith
→ CopyWith$Input$WidgetIntegrationContentGamesInput<
Input$WidgetIntegrationContentGamesInput> -
no setter
- enable → bool?
-
no setter
- football → bool?
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override