Input$WidgetIntegrationScaleInput class

Constructors

Input$WidgetIntegrationScaleInput({double? web, double? mobile})
factory
Input$WidgetIntegrationScaleInput.fromJson(Map<String, dynamic> data)
factory

Properties

copyWith CopyWith$Input$WidgetIntegrationScaleInput<Input$WidgetIntegrationScaleInput>
no setter
hashCode int
The hash code for this object.
no setteroverride
mobile double?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
web double?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override