Input$addRewardInput class

Constructors

Input$addRewardInput({Input$TargetACIInput? target, String? game, required int year, required int cycleNumber, required Enum$LeaderboardCycleEnum cycle, String? gameGroup, required List<Input$GameIntegrationRewardInnerInput> rewards})
factory
Input$addRewardInput.fromJson(Map<String, dynamic> data)
factory

Properties

copyWith CopyWith$Input$addRewardInput<Input$addRewardInput>
no setter
cycle Enum$LeaderboardCycleEnum
no setter
cycleNumber int
no setter
game String?
no setter
gameGroup String?
no setter
hashCode int
The hash code for this object.
no setteroverride
rewards List<Input$GameIntegrationRewardInnerInput>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Input$TargetACIInput?
no setter
year int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override