CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage<TRes> class
abstract
Constructors
- CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage(Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage instance, TRes then(Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage))
-
factory
- CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage.stub(TRes res)
-
factory
Properties
-
custom
→ CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$custom<
TRes> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
location
→ CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$location<
TRes> -
no setter
-
media
→ CopyWith$Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{String? text, String? gif, String? sticker, Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$media? media, Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$location? location, Mutation$sendMessageToTarget$sendMessageToTarget$messageGroup$lastMessage$custom? custom, bool? unread, DateTime? createdAt, DateTime? updatedAt}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited