CopyWith$Mutation$updateUser$updateUser$residentialAddress<TRes> class
abstract
Constructors
Properties
-
country
→ CopyWith$Mutation$updateUser$updateUser$residentialAddress$country<
TRes> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
location
→ CopyWith$Mutation$updateUser$updateUser$residentialAddress$location<
TRes> -
no setter
-
owner
→ CopyWith$Mutation$updateUser$updateUser$residentialAddress$owner<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
→ CopyWith$Mutation$updateUser$updateUser$residentialAddress$state<
TRes> -
no setter
Methods
-
call(
{String? city, String? address, String? postCode, Mutation$updateUser$updateUser$residentialAddress$location? location, Mutation$updateUser$updateUser$residentialAddress$country? country, Mutation$updateUser$updateUser$residentialAddress$state? state, Mutation$updateUser$updateUser$residentialAddress$owner? owner}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited