Query$user$user$work class
- Available extensions
Constructors
-
Query$user$user$work({String? company, String? position, String? description, Query$user$user$work$city? city, Query$user$user$work$country? country, List<
String> ? tags, DateTime? from, DateTime? to, bool? current}) -
Query$user$user$work.fromJson(Map<
String, dynamic> json) -
factory
Properties
- city → Query$user$user$work$city?
-
final
- company → String?
-
final
-
copyWith
→ CopyWith$Query$user$user$work<
Query$user$user$work> -
Available on Query$user$user$work, provided by the UtilityExtension$Query$user$user$work extension
no setter - country → Query$user$user$work$country?
-
final
- current → bool?
-
final
- description → String?
-
final
- from → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- position → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- to → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override