CopyWith$Input$GameGroupInput<TRes> class
abstract
Constructors
- CopyWith$Input$GameGroupInput(Input$GameGroupInput instance, TRes then(Input$GameGroupInput))
-
factory
- CopyWith$Input$GameGroupInput.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
leaderboard
→ CopyWith$Input$GameIntegrationLeaderboardInput<
TRes> -
no setter
-
picture
→ CopyWith$Input$PictureInput<
TRes> -
no setter
-
point
→ CopyWith$Input$GamePointInput<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{String? name, String? code, Input$PictureInput? picture, bool? enable, List< String> ? games, Input$GamePointInput? point, Input$GameIntegrationLeaderboardInput? leaderboard, List<Input$GameIntegrationRewardsSchedularInput> ? rewardsSchedular}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rewardsSchedular(
Iterable< Input$GameIntegrationRewardsSchedularInput> ? _fn(Iterable<CopyWith$Input$GameIntegrationRewardsSchedularInput< ?)) → TResInput$GameIntegrationRewardsSchedularInput> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited