CopyWith$Input$GameSettingsItemInput<TRes> class
abstract
Constructors
- CopyWith$Input$GameSettingsItemInput(Input$GameSettingsItemInput instance, TRes then(Input$GameSettingsItemInput))
-
factory
- CopyWith$Input$GameSettingsItemInput.stub(TRes res)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
picture
→ CopyWith$Input$PictureInput<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{String? title, String? description, Input$PictureInput? picture, String? emoji, String? color, double? weight, bool? isRare, String? points, String? fallback, String? qualitative, bool? empty, bool? again, String? price}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited