CopyWith$Input$GenerateInsightsInput<TRes> class
abstract
Constructors
- CopyWith$Input$GenerateInsightsInput(Input$GenerateInsightsInput instance, TRes then(Input$GenerateInsightsInput))
-
factory
- CopyWith$Input$GenerateInsightsInput.stub(TRes res)
-
factory
Properties
-
breakdowns
→ CopyWith$Input$InsightsBreakdownsInput<
TRes> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
kpis
→ CopyWith$Input$InsightsKpisInput<
TRes> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
{Input$InsightsKpisInput? kpis, Input$InsightsBreakdownsInput? breakdowns, List< String> ? topCampaigns, List<String> ? underperformingCampaigns, String? language, String? tone}) → TRes -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited