Input$CurrentRewardsFilterInput class
Constructors
- Input$CurrentRewardsFilterInput({required Input$TargetACIInput target, String? gameCode, String? gameId, String? gameGroup})
-
factory
-
Input$CurrentRewardsFilterInput.fromJson(Map<
String, dynamic> data) -
factory
Properties
-
copyWith
→ CopyWith$Input$CurrentRewardsFilterInput<
Input$CurrentRewardsFilterInput> -
no setter
- gameCode → String?
-
no setter
- gameGroup → String?
-
no setter
- gameId → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- target → Input$TargetACIInput
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override