Input$GameGroupInput class
Constructors
-
Input$GameGroupInput({required String name, required String code, Input$PictureInput? picture, bool? enable, List<
String> ? games, Input$GamePointInput? point, Input$GameIntegrationLeaderboardInput? leaderboard, List<Input$GameIntegrationRewardsSchedularInput> ? rewardsSchedular}) -
factory
-
Input$GameGroupInput.fromJson(Map<
String, dynamic> data) -
factory
Properties
- code → String
-
no setter
-
copyWith
→ CopyWith$Input$GameGroupInput<
Input$GameGroupInput> -
no setter
- enable → bool?
-
no setter
-
games
→ List<
String> ? -
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- leaderboard → Input$GameIntegrationLeaderboardInput?
-
no setter
- name → String
-
no setter
- picture → Input$PictureInput?
-
no setter
- point → Input$GamePointInput?
-
no setter
-
rewardsSchedular
→ List<
Input$GameIntegrationRewardsSchedularInput> ? -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override