Input$GameSettingsItemInput class
Constructors
- Input$GameSettingsItemInput({required String title, required String description, required Input$PictureInput picture, String? emoji, String? color, double? weight, bool? isRare, String? points, String? fallback, String? qualitative, required bool empty, required bool again, String? price})
-
factory
-
Input$GameSettingsItemInput.fromJson(Map<
String, dynamic> data) -
factory
Properties
- again → bool
-
no setter
- color → String?
-
no setter
-
copyWith
→ CopyWith$Input$GameSettingsItemInput<
Input$GameSettingsItemInput> -
no setter
- description → String
-
no setter
- emoji → String?
-
no setter
- empty → bool
-
no setter
- fallback → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- isRare → bool?
-
no setter
- picture → Input$PictureInput
-
no setter
- points → String?
-
no setter
- price → String?
-
no setter
- qualitative → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
no setter
- weight → double?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override