Input$InsightsBreakdownsInput class
Constructors
-
Input$InsightsBreakdownsInput({required List<
String> topCountries, required String topDevice, required String weakDevice}) -
factory
-
Input$InsightsBreakdownsInput.fromJson(Map<
String, dynamic> data) -
factory
Properties
-
copyWith
→ CopyWith$Input$InsightsBreakdownsInput<
Input$InsightsBreakdownsInput> -
no setter
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
topCountries
→ List<
String> -
no setter
- topDevice → String
-
no setter
- weakDevice → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override